pub struct Cells(pub Vec<Cell>);Expand description
A simple wrapper type for a Vec<Cell>.
This wrapper is needed to support generic conversions between iterables and Vec<Cell>.
Check the trait implementations for more docs.
Tuple Fields
0: Vec<Cell>Trait Implementations
Sourceimpl<T> From<T> for Cells
Allow the conversion of a type to a Cells, which is a simple vector of cells.
impl<T> From<T> for Cells
Allow the conversion of a type to a Cells, which is a simple vector of cells.
By default this is implemented for all Iterators over items implementing ToString.
use comfy_table::{Cells, Row};
let cells_string: Cells = vec!["One", "Two", "Three"].into();
let cells_integer: Cells = vec![1, 2, 3, 4].into();Auto Trait Implementations
impl Freeze for Cells
impl RefUnwindSafe for Cells
impl Send for Cells
impl Sync for Cells
impl Unpin for Cells
impl UnsafeUnpin for Cells
impl UnwindSafe for Cells